# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.3

([Full Changelog](https://github.com/agoose77/gennaker-tools/compare/c2dd80b54b1294fd7c581c9f1ca9241b02338093...3c9e5e267bd3b2d002290e79e9949a370bdeac79))

### Maintenance and upkeep improvements

- deps: Update gha to v6 (major) [#12](https://github.com/agoose77/gennaker-tools/pull/12) ([@renovate](https://github.com/renovate))
- deps: Update dependency python to v3.14.1 [#11](https://github.com/agoose77/gennaker-tools/pull/11) ([@renovate](https://github.com/renovate))
- deps: Update gha (major) [#6](https://github.com/agoose77/gennaker-tools/pull/6) ([@renovate](https://github.com/renovate))
- deps: Update dependency python to v3.14.0 [#5](https://github.com/agoose77/gennaker-tools/pull/5) ([@renovate](https://github.com/renovate))

### Other merged PRs

- Fix: more release fixes [#14](https://github.com/agoose77/gennaker-tools/pull/14) ([@agoose77](https://github.com/agoose77))
- fix: release workflow [#13](https://github.com/agoose77/gennaker-tools/pull/13) ([@agoose77](https://github.com/agoose77))
- Fix: cleanup exit logic, and guard reconciliation loop [#10](https://github.com/agoose77/gennaker-tools/pull/10) ([@agoose77](https://github.com/agoose77))
- Feat: add support for CodeMirror snippets [#9](https://github.com/agoose77/gennaker-tools/pull/9) ([@agoose77](https://github.com/agoose77))
- Feat: add TOML settings synchronisation. [#8](https://github.com/agoose77/gennaker-tools/pull/8) ([@agoose77](https://github.com/agoose77))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/agoose77/gennaker-tools/graphs/contributors?from=2025-07-24&to=2025-12-23&type=c))

[@agoose77](https://github.com/search?q=repo%3Aagoose77%2Fgennaker-tools+involves%3Aagoose77+updated%3A2025-07-24..2025-12-23&type=Issues) | [@renovate](https://github.com/search?q=repo%3Aagoose77%2Fgennaker-tools+involves%3Arenovate+updated%3A2025-07-24..2025-12-23&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.2

([Full Changelog](https://github.com/agoose77/gennaker-tools/compare/v0.1.1...b7c19f098d01aced82088abd2524a0f3b1377b04))

### Merged PRs

- fix: release workflow [#13](https://github.com/agoose77/gennaker-tools/pull/13) ([@agoose77](https://github.com/agoose77))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/agoose77/gennaker-tools/graphs/contributors?from=2025-12-23&to=2025-12-23&type=c))

[@agoose77](https://github.com/search?q=repo%3Aagoose77%2Fgennaker-tools+involves%3Aagoose77+updated%3A2025-12-23..2025-12-23&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/agoose77/gennaker-tools/compare/c2dd80b54b1294fd7c581c9f1ca9241b02338093...9ac2a1e40a03fbd9745d36bdac84bbd72bfedcc4))

### Maintenance and upkeep improvements

- deps: Update gha to v6 (major) [#12](https://github.com/agoose77/gennaker-tools/pull/12) ([@renovate](https://github.com/renovate))
- deps: Update dependency python to v3.14.1 [#11](https://github.com/agoose77/gennaker-tools/pull/11) ([@renovate](https://github.com/renovate))
- deps: Update gha (major) [#6](https://github.com/agoose77/gennaker-tools/pull/6) ([@renovate](https://github.com/renovate))
- deps: Update dependency python to v3.14.0 [#5](https://github.com/agoose77/gennaker-tools/pull/5) ([@renovate](https://github.com/renovate))

### Other merged PRs

- Fix: cleanup exit logic, and guard reconciliation loop [#10](https://github.com/agoose77/gennaker-tools/pull/10) ([@agoose77](https://github.com/agoose77))
- Feat: add support for CodeMirror snippets [#9](https://github.com/agoose77/gennaker-tools/pull/9) ([@agoose77](https://github.com/agoose77))
- Feat: add TOML settings synchronisation. [#8](https://github.com/agoose77/gennaker-tools/pull/8) ([@agoose77](https://github.com/agoose77))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/agoose77/gennaker-tools/graphs/contributors?from=2025-07-24&to=2025-12-23&type=c))

[@agoose77](https://github.com/search?q=repo%3Aagoose77%2Fgennaker-tools+involves%3Aagoose77+updated%3A2025-07-24..2025-12-23&type=Issues) | [@renovate](https://github.com/search?q=repo%3Aagoose77%2Fgennaker-tools+involves%3Arenovate+updated%3A2025-07-24..2025-12-23&type=Issues)
